@@ -1,5 +1,6 @@
 """Wall Pad Imazu Socket Client"""
 import logging
+from typing import Optional
 
 from wp_socket.client import WpSocketClient
 
@@ -21,7 +22,7 @@ def checksum(packet: bytes) -> bool:
     return packet[len(packet) - 2] == p_sum
 
 
-def makesum(packet: bytes):
+def makesum(packet: bytes) -> Optional[int]:
     """Imazu packet make checksum"""
     if len(packet) < packet[1] - 2:
         return None
@@ -51,7 +52,12 @@ class ImazuClient(WpSocketClient):
         data.append(0)  # checksum
         data.extend(PACKET_TAIL)
         data[1] = len(data)  # len
-        data[-2] = makesum(data)  # checksum
+
+        # checksum
+        if (_makesum := makesum(data)) is None:
+            _LOGGER.warning('send invalid makesum: %s', data.hex())
+            return
+        data[-2] = _makesum
 
         if not checksum(packet):
             _LOGGER.warning('send invalid packet: %s', data.hex())
@@ -68,9 +74,6 @@ class ImazuClient(WpSocketClient):
                     _LOGGER.warning('receive invalid packet: %s', packet.hex())
                     continue
                 imazu_packets = parse_packet(packet.hex())
-                if not imazu_packets:
-                    continue
-
                 for imazu_packet in imazu_packets:
                     _LOGGER.debug(imazu_packet.description())
                     await self.async_packet_handler(imazu_packet)
@@ -86,15 +89,13 @@ class ImazuClient(WpSocketClient):
             self.prev_packets = None
 
         while packets:
-            start_idx = packets.find(PACKET_HEADER)
-            if start_idx == -1:
+            if (start_idx := packets.find(PACKET_HEADER)) == -1:
                 _LOGGER.warning('unknown packets %s', packets.hex())
                 break
             if start_idx != 0:
                 _LOGGER.warning('unknown start packets %s', packets.hex())
 
-            end_idx = packets.find(PACKET_TAIL, start_idx + 8)
-            if end_idx == -1:
+            if (end_idx := packets.find(PACKET_TAIL, start_idx + 8)) == -1:
                 self.prev_packets = packets
                 break
             packet_list.append(packets[start_idx: end_idx + 1])
