@@ -1,9 +1,10 @@
 """Wall Pad Imazu Packet"""
+
 import copy
 import logging
 from abc import ABC
 from enum import Enum
-from typing import Any, Optional
+from typing import Optional
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -47,49 +48,6 @@ class ValueType(Enum):
     ACMODE = "5c"
 
 
-def parse_packet(packet: str):
-    """Packet parse"""
-    packets = [packet[i: i + 2] for i in range(0, len(packet), 2)]
-
-    def _parse_imazu_packet():
-        """Imazu packet Parse"""
-        device = packets[3]
-        if device == '16':
-            return GuardPacket(packets)
-        if device == '18':
-            return ThermostatPacket(packets)
-        if device == '19':
-            return LightPacket(packets)
-        if device == '1a':
-            return DimmingPacket(packets)
-        if device == '1b':
-            return GasPacket(packets)
-        if device == '1c':
-            return AcPacket(packets)
-        if device == '1f':
-            return SwitchPacket(packets)
-        if device == '2a':
-            return AwayModePacket(packets)
-        if device == '2b':
-            return FanPacket(packets)
-        _LOGGER.warning('unknown device, %s, %s', device, packets)
-        return None
-
-    imazu_packet = _parse_imazu_packet()
-    if imazu_packet is None:
-        return None
-
-    if imazu_packet.cmd in [Cmd.SCAN, Cmd.CHANGE]:
-        return None
-
-    if imazu_packet.cmd != Cmd.STATUS:
-        _LOGGER.warning('%s unknown cmd, %s, %s',
-                        imazu_packet.device.name, imazu_packet.cmd, ''.join(packets))
-        return None
-
-    return imazu_packet.parse_state_packets()
-
-
 class ImazuPacket(ABC):
     """Abstract imazu packet
     0: f7
@@ -121,26 +79,26 @@ class ImazuPacket(ABC):
         self.checksum = packet[-2:-1]
 
     @property
-    def name(self):
+    def name(self) -> str:
         """Name"""
         return self.device.name
 
     @property
-    def room_id(self):
+    def room_id(self) -> int:
         """RoomId"""
         return int(self.sub[:1], 16)
 
     @property
-    def sub_id(self):
+    def sub_id(self) -> int:
         """SubId"""
         return int(self.sub[1:2], 16)
 
     @property
-    def device_id(self):
+    def device_id(self) -> str:
         """DeviceId"""
         return f'{self.device.value}_{self.room_id}_{self.sub_id}'
 
-    def description(self):
+    def description(self) -> str:
         """Description"""
         desc = f'{self.cmd.name}: {self.name}({self.device_id})'
         if self.cmd == Cmd.SCAN:
@@ -149,13 +107,18 @@ class ImazuPacket(ABC):
             return f'{desc}, change: {" ".join(self.change_value)}'
         if self.cmd == Cmd.STATUS:
             return f'{desc}, state: {" ".join(self.state_value)}'
-        return None
+        return desc
 
-    def parse_state_packets(self) -> Any:
+    def hex(self) -> str:
+        """Create a str of hexadecimal numbers from a ImazuPacket object."""
+        return ''.join(self.packet)
+
+    def parse_state_packets(self) -> list:
         """State packet Parse"""
         _LOGGER.warning('%s not implement set status, %s', self.name, ''.join(self.packet))
+        return []
 
-    def _copy_state_packets(self, states: list[list[str]], parse_state):
+    def _copy_state_packets(self, states: list[list[str]], parse_state) -> list:
         """State packet Copy"""
         packets = []
         for idx in list(range(len(states))):
@@ -166,7 +129,7 @@ class ImazuPacket(ABC):
             packets.append(packet)
         return packets
 
-    def _make_base(self, cmd: Cmd, value_type: ValueType) -> bytearray:
+    def make_base(self, cmd: Cmd, value_type: ValueType) -> bytearray:
         """Base packet Make"""
         # 01 or 1a, device, cmd, value_type, sub, change_value, state_value
         packet: bytearray = bytearray.fromhex(self.type + str(self.device.value))
@@ -175,9 +138,9 @@ class ImazuPacket(ABC):
         packet.append(int(self.sub, 16))
         return packet
 
-    def _make_scan(self, value_type: ValueType) -> bytearray:
+    def make_scan(self, value_type: ValueType) -> bytearray:
         """Scan packet Make"""
-        packet = self._make_base(Cmd.SCAN, value_type)
+        packet = self.make_base(Cmd.SCAN, value_type)
         packet.append(0)
         packet.append(0)
         return packet
@@ -214,7 +177,7 @@ class ThermostatPacket(ImazuPacket):
         OFF = "04"
         AWAY = "07"
 
-    def parse_state_packets(self) -> Optional[list]:
+    def parse_state_packets(self) -> list:
         """State packet Parse"""
         if self.value_type == ValueType.MODE:
             if len(self.state_value) % 3 == 0:
@@ -236,25 +199,25 @@ class ThermostatPacket(ImazuPacket):
                 return [self]
 
             _LOGGER.warning('%s unknown thermostat, %s', self.name, ''.join(self.packet))
-            return None
+            return []
         _LOGGER.warning('%s unknown state packet, %s, %s',
                         self.name, self.value_type.value, ''.join(self.packet))
-        return None
+        return []
 
-    def make_scan(self) -> bytearray:
+    def make_scan_mode(self) -> bytearray:
         """Scan packet Make"""
-        return self._make_scan(ValueType.MODE)
+        return self.make_scan(ValueType.MODE)
 
-    def make_mode(self, mode: Mode) -> bytearray:
+    def make_change_mode(self, mode: Mode) -> bytearray:
         """Mode packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.MODE)
+        packet = super().make_base(Cmd.CHANGE, ValueType.MODE)
         packet.append(int(str(mode.value), 16))
         packet.append(0)
         return packet
 
-    def make_target_temp(self, temp: int) -> bytearray:
+    def make_change_target_temp(self, temp: int) -> bytearray:
         """Target temp packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.TEMP)
+        packet = super().make_base(Cmd.CHANGE, ValueType.TEMP)
         packet.append(temp)
         packet.append(0)
         return packet
@@ -281,7 +244,7 @@ class LightPacket(ImazuPacket):
         ON = "01"
         OFF = "02"
 
-    def parse_state_packets(self) -> Optional[list]:
+    def parse_state_packets(self) -> list:
         """State packet Parse"""
         if self.value_type == ValueType.BOOL:
 
@@ -300,15 +263,15 @@ class LightPacket(ImazuPacket):
 
         _LOGGER.warning('%s unknown state packet, %s, %s',
                         self.name, self.value_type.value, ''.join(self.packet))
-        return None
+        return []
 
-    def make_scan(self) -> bytearray:
+    def make_scan_bool(self) -> bytearray:
         """Scan packet Make"""
-        return self._make_scan(ValueType.BOOL)
+        return self.make_scan(ValueType.BOOL)
 
-    def make_power(self, power: Power) -> bytearray:
+    def make_change_power(self, power: Power) -> bytearray:
         """Power packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.BOOL)
+        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
         packet.append(int(str(power.value), 16))
         packet.append(0)
         return packet
@@ -336,7 +299,7 @@ class GasPacket(ImazuPacket):
         CLOSE = "03"
         OPEN = "04"
 
-    def parse_state_packets(self) -> Optional[list]:
+    def parse_state_packets(self) -> list:
         """State packet Parse"""
         if self.value_type == ValueType.VALVE:
             self.state = {'valve': GasPacket.Valve(self.state_value[0])}
@@ -344,19 +307,19 @@ class GasPacket(ImazuPacket):
 
         _LOGGER.warning('%s unknown state packet, %s, %s',
                         self.name, self.value_type.value, ''.join(self.packet))
-        return None
+        return []
 
-    def make_valve_close(self) -> bytearray:
+    def make_scan_valve(self) -> bytearray:
+        """Scan packet Make"""
+        return self.make_scan(ValueType.VALVE)
+
+    def make_change_valve_close(self) -> bytearray:
         """Valve close packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.VALVE)
+        packet = super().make_base(Cmd.CHANGE, ValueType.VALVE)
         packet.append(int(GasPacket.Valve.CLOSE.value, 16))
         packet.append(0)
         return packet
 
-    def make_scan(self) -> bytearray:
-        """Scan packet Make"""
-        return self._make_scan(ValueType.VALVE)
-
 
 class AcPacket(ImazuPacket):
     """Imazu ac packet"""
@@ -385,7 +348,7 @@ class SwitchPacket(ImazuPacket):
         ON = "01"
         OFF = "02"
 
-    def parse_state_packets(self) -> Optional[list]:
+    def parse_state_packets(self) -> list:
         """State packet Parse"""
         if self.value_type == ValueType.BOOL:
 
@@ -405,15 +368,15 @@ class SwitchPacket(ImazuPacket):
 
         _LOGGER.warning('%s unknown state value_type: %s, %s',
                         self.name, self.value_type.value, ''.join(self.packet))
-        return None
+        return []
 
-    def make_scan(self) -> bytearray:
+    def make_scan_bool(self) -> bytearray:
         """Scan packet Make"""
-        return self._make_scan(ValueType.BOOL)
+        return self.make_scan(ValueType.BOOL)
 
-    def make_power(self, power: Power) -> bytearray:
+    def make_change_power(self, power: Power) -> bytearray:
         """Power packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.BOOL)
+        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
         packet.append(int(str(power.value), 16))
         packet.append(0)
         return packet
@@ -435,7 +398,7 @@ class AwayModePacket(ImazuPacket):
         CLOSE = "03"
         OPEN = "04"
 
-    def parse_state_packets(self) -> Optional[list]:
+    def parse_state_packets(self) -> list:
         """State packet Parse"""
         if self.value_type == ValueType.BOOL:
             def parse_state(state_value: list[str]):
@@ -446,28 +409,28 @@ class AwayModePacket(ImazuPacket):
                     return {'valve': AwayModePacket.Valve(state_value[1])}
                 _LOGGER.warning('%s unknown state device: %s, %s',
                                 self.name, self.device.name, ''.join(self.packet))
-                return None
+                return {}
 
             states = [self.state_value[i: i + 2] for i in range(0, len(self.state_value), 2)]
             return super()._copy_state_packets(states, parse_state)
         _LOGGER.warning('%s unknown state value_type: %s, %s',
                         self.name, self.value_type.value, ''.join(self.packet))
-        return None
+        return []
 
-    def make_scan(self) -> bytearray:
+    def make_scan_bool(self) -> bytearray:
         """Scan packet Make"""
-        return self._make_scan(ValueType.BOOL)
+        return self.make_scan(ValueType.BOOL)
 
-    def make_power(self, power: Power) -> bytearray:
+    def make_change_power(self, power: Power) -> bytearray:
         """Power packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.BOOL)
+        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
         packet.append(int(str(power.value), 16))
         packet.append(0)
         return packet
 
-    def make_valve(self, valve: Valve) -> bytearray:
+    def make_change_valve(self, valve: Valve) -> bytearray:
         """Vavle packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.VALVE)
+        packet = super().make_base(Cmd.CHANGE, ValueType.VALVE)
         packet.append(int(str(valve.value), 16))
         packet.append(0)
         return packet
@@ -510,7 +473,7 @@ class FanPacket(ImazuPacket):
         MEDIUM = "03"
         HIGH = "07"
 
-    def parse_state_packets(self) -> Optional[list]:
+    def parse_state_packets(self) -> list:
         """State packet Parse"""
         if len(self.state_value) > 2:
             _LOGGER.warning('%s unknown more status, %s, %s',
@@ -538,22 +501,64 @@ class FanPacket(ImazuPacket):
 
         _LOGGER.warning('%s unknown state value_type: %s, %s',
                         self.name, self.value_type.value, ''.join(self.packet))
-        return None
+        return []
 
-    def make_scan(self) -> bytearray:
+    def make_scan_bool(self) -> bytearray:
         """Scan packet Make"""
-        return self._make_scan(ValueType.BOOL)
+        return self.make_scan(ValueType.BOOL)
 
-    def make_power_off(self) -> bytearray:
+    def make_change_power_off(self) -> bytearray:
         """Power off packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.BOOL)
+        packet = super().make_base(Cmd.CHANGE, ValueType.BOOL)
         packet.append(int(FanPacket.Power.OFF.value, 16))
         packet.append(0)
         return packet
 
-    def make_speed(self, speed: Speed) -> bytearray:
+    def make_change_speed(self, speed: Speed) -> bytearray:
         """Speed packet Make"""
-        packet = super()._make_base(Cmd.CHANGE, ValueType.DIM)
+        packet = super().make_base(Cmd.CHANGE, ValueType.DIM)
         packet.append(int(str(speed.value), 16))
         packet.append(0)
         return packet
+
+
+def parse_packet(packet: str) -> list[ImazuPacket]:
+    """Packet parse"""
+    packets = [packet[i: i + 2] for i in range(0, len(packet), 2)]
+
+    def _parse_imazu_packet() -> Optional[ImazuPacket]:
+        """Imazu packet Parse"""
+        device = packets[3]
+        if device == '16':
+            return GuardPacket(packets)
+        if device == '18':
+            return ThermostatPacket(packets)
+        if device == '19':
+            return LightPacket(packets)
+        if device == '1a':
+            return DimmingPacket(packets)
+        if device == '1b':
+            return GasPacket(packets)
+        if device == '1c':
+            return AcPacket(packets)
+        if device == '1f':
+            return SwitchPacket(packets)
+        if device == '2a':
+            return AwayModePacket(packets)
+        if device == '2b':
+            return FanPacket(packets)
+        _LOGGER.warning('unknown device, %s, %s', device, packets)
+        return None
+
+    if (imazu_packet := _parse_imazu_packet()) is None:
+        return []
+
+    if imazu_packet.cmd in [Cmd.SCAN, Cmd.CHANGE]:
+        return []
+
+    if imazu_packet.cmd != Cmd.STATUS:
+        _LOGGER.warning('%s unknown cmd, %s, %s',
+                        imazu_packet.device.name, imazu_packet.cmd, ''.join(packets))
+        return []
+
+    return imazu_packet.parse_state_packets()
